# helperLTE

Bu kitabxana, şəkil emalı və model təlimi kimi maşın öyrənmə tapşırıqları üçün müxtəlif yardımçı funksiyaları təmin edir.

## Əsas Xüsusiyyətlər:

* Zip fayllarını açma
* Şəkil datasetləri üçün orta (mean) və standart sapma (std) hesablama
* Şəkil çevirmələri və data gücləndirmə (augmentation) üçün kompozisiyalar yaratma
* Pytorch `DataLoader` obyektlərini hazırlama
* ResNet18 modelini təlim etmə
* Təlim edilmiş modelləri qiymətləndirmə

## Quraşdırma

Kitabxananı PIP vasitəsilə quraşdırmaq üçün aşağıdakı əmri işlədin:

```bash
pip install helperLTE
